package Local::Irclog::Bitchx;

use 5.006;
use strict;
use warnings;

BEGIN {
	use Exporter ();
	our ( $VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
	$VERSION    = .01;
	@ISA        = qw/ Exporter /;
	@EXPORT     = qw/ &gethash %bx /;
	@EXPORT_OK  = qw/ &clean /;
}

use vars qw/%bx
		/;
			
# TODO: maybe think of something to do if timestamping is turned on. possibly
# just dump it in sub clean, or put it into the hash with another sub.  Hmmm.

sub clean	{
    my $wrk = $_[0];
    # getting rid of the ANSI color codes
    	# BitchX version BitchX-1.0c17 
	$wrk =~ s/\003[0-9]+//g;
	$wrk =~ s/\003//g;
	$wrk =~ s/\002//g;
	$wrk =~ s/\017//g;
    	# BitchX version BitchX-1.0c18 
    $wrk =~ s/\033\[[0-9;]+m//g;
    # Taking care of the \ escape
    $wrk =~ s/\\/ escape /g;
    # Taking care of the "$" dollar sign 
	#$wrk =~ s/\$/\\\$/g;
	#$wrk =~ s/\`//g;

	chomp($wrk);
	return $wrk;
}
	
sub gethash	{
    my $wrk = &clean($_[0]);
	#$wrk = &clean($wrk);
	my $chr = chr(240);	
	undef %bx;		
	
	if($wrk =~ s/^<//)	{	
		$wrk =~ s/>(.*)$//;
		$bx{'name'} = "$wrk";
		$bx{'content'} = $1;
		$bx{'type'} = "regular";
	}	
		elsif($wrk =~ s/^[\*$chr]\s+//)	{
			$wrk =~ s/\s(.*)$//;
			$bx{'name'} = $wrk;
			$bx{'content'} = $1;
			$bx{'type'} = "me";
		}	
		elsif($wrk =~ s/^\[//)	{
			if ($wrk =~ s/^msg\(([^\)]+)\)\]//)	{
				$bx{'name'} = $1;
				$bx{'type'} = "msg_to";
				$bx{'content'} = $wrk;
			}
			elsif ($wrk =~ s/([^\(]+).+?\)\]//)	{
				$bx{'name'} = $1;
				$bx{'type'} = "msg_from";
				$bx{'content'} = $wrk;
			}
		}
		elsif($wrk =~ s/^-:-\s+//)	{
			if($wrk =~ s/\s+\[.*\]\s+has\s+joined\s+#(\w+)//)	{
				$bx{'name'} = $wrk;
				$bx{'chan'} = $1;
				$bx{'type'} = "joined";
			}
			elsif($wrk =~ s/^SignOff\s//)   {
				$wrk =~ s/([-\S]+):\s+#(\w+)\s+//;
				$bx{'name'} = $1;
				$bx{'chan'} = $2;
				$bx{'type'} = "signoff";
				if($wrk =~ /Ping\stimeout/)	{
					$bx{'content'} = "ping timeout";
				}
					elsif($wrk =~ /Reconnecting/)	{
						$bx{'content'} = "Reconnecting";
					}
					else	{
						$wrk =~ s/[\(\)]//g;
						$bx{'content'} = $wrk;
					}
				}
			elsif($wrk =~ s/^Topic\s+\(#(\w+)\):\s+//)	{
				$bx{'chan'} = $1;
				$bx{'content'} = $wrk;
				$bx{'type'} = "topic";
			}
		}
}
1;


__END__

=head1 NAME

Local::Irclog::Bitchx - Perl extension for getting certain information from an
IrcLog.

=head1 SYNOPSIS

  use Local::Irclog::Bitchx;

  my $irclog = 'Irclog.sample';

  open (IRC, "<$irclog") || die "couldn't open $irclog for reading";
  while ($line = <IRC>) {
    &gethash($line);

    if(! %bx)   {
        print "This line not parsed\n";
        next;
    } 
        else    {
            while ( ($key, $value) = each %bx) {
                print "$key => $value\n";
            }
        }
        print "\n\n"
    }


This module is meant to be used with bx2fest and probably not very useful for 
anything else.

=head1 DESCRIPTION

Local::Irclog::Bitchx is a module for getting the interesting bits out of a
BitchX IrcLog.  The module exports the function &gethash and returns the hash
%bx.

The subroutine &gethash expects a line from a BtichX IrcLog and if it is a
line of the sort it supports it will return a hash %bx. %bx will contain at
least the key/value for %bx{type} and it may be any of the following: 

=over 4

=item * regular

 A line in which someone addresses the channel.
  <Debiot> perl rox
 This would give the following values:
  $bx{type} => 'regular'
  $bx{name} => 'Debiot'
  $bx{content} => 'perl rox'

=item * me

 Lines in which the speaker has typed /me something.
   ascii thinks perl rox
 This would give the following values:
  $bx{type} => 'me'
  $bx{name} => 'ascii'
  $bx{content} => 'thinks perl rox'

=item * joined

 Lines that announce that someone has joined the channel.
  -:- doppler [david@cs2890-153.austin.rr.com] has joined #alg
 This would give the following values:
  $bx{type} => 'joined'
  $bx{name} => 'doppler'
  $bx{chan} => 'alg'

=item * signoff

 Lines that announce that someone has left the channel.
  -:- SignOff The_Dome: #alg (BitchX: EPIC on steroids.)
 This would give the following values:
  $bx{type} => 'signoff'
  $bx{name} => 'The_Dome'
  $bx{chan} => 'alg'
  $bx{content} => 'BitchX: EPIC on steroids.'

=item * topic

 A line that tells what the topic for a channel is.
  -:- Topic (#alg): perl rox
 This would give the following values:
  $bx{type} => 'topic'
  $bx{chan} => 'alg'
  $bx{content} => 'perl rox.'

=item * msg_to

 A private message to someone.
  [msg(ascii)] [Cadet] is too Bill Gate's personal shoeshine boy
 This would give the following values:
  $bx{type} => 'msg_to'
  $bx{name} => 'ascii'
  $bx{content} => '[Cadet] is Bill Gate's personal shoeshine boy'

=item * msg_from

 A private message from someone.
  [ascii(~ascii@foo.bar.net)] Yes he is
 This would give the following values:
   $bx{type} => 'msg_from'
   $bx{name} => 'ascii'
   $bx{content} => 'Yes he is'

=back

=head2 EXPORT

sub gethash is exported and returns %bx which is also exported. Export is
allowed for sub clean, which just returns the line without all the ansii color
codes.


=head1 AUTHOR

Mick McMillan, E<lt>mick@lowdrag.orgE<gt>

=head1 SEE ALSO

L<perl>.

=cut
